Package 'rippo'

Title: Simplify AAGI-CU IPPO Register Updates
Description: Helper functions that ease preparing the AAGI IPPO register from creating third party background IP tables to generating IPPO reports on a project by project basis.
Authors: Adam H. Sparks [cre, aut] (ORCID: <https://orcid.org/0000-0002-0061-8359>), Zhanglong Cao [aut] (Wrote original `create_table_3()`., ORCID: <https://orcid.org/0000-0001-6667-9392>), Braden Thorne [aut] (Contributed the Shiny app for generating IPPO register tables., ORCID: <https://orcid.org/0000-0003-0497-1675>), Grains Research and Development Corporation [fnd, cph] (GRDC Project CUR2210-005OPX (AAGI-CU), ROR: <https://ror.org/02xwr1996>)
Maintainer: Adam H. Sparks <[email protected]>
License: MIT + file LICENSE
Version: 1.0.3
Built: 2026-06-04 11:14:10 UTC
Source: https://github.com/AAGI-AUS/rippo

Help Index


Create an IPPO register report for GRDC

Description

Create an IPPO register report for GRDC

Usage

create_ippo_report(tables_list, sp, outfile)

Arguments

tables_list

A nested list of IPPO register data tables for AAGI service and support and research and development projects for reporting generated with list_ippo_tables().

sp

A character string providing the AAGI strategic partner that is generating the report, can be full name or two letter string used by AAGI.

outfile

A filename including the file path where the file is to be written. The output file is an MS Word(TM) document that follows AAGI style guidelines.

Value

An invisible NULL, called for its side-effects of generating an MS Word(TM) document with tables that report each project's IPPO.

See Also

Other reporting: list_ippo_tables()

Examples

# for macOS
 library(fs)
 sp <- "CU" # strategic partner for report
 R_drive <- "/Volumes/dmp/A-J/AAGI_CCDM_CBADA-GIBBEM-SE21982/"
 tl <- list_ippo_tables(
   dir_path_in = path(R_drive, "Projects"),
   sp = sp
 )
create_ippo_report(tables_list = tl,
                   sp = sp,
                   outfile = "~/AAGI-CU-IPPO-register.docx"
                   )

Create a Table of Third Party IP (Table 3) of the R packages used for an AAGI IPPO document

Description

Automatically recognises R packages that are used in a project and generates Table 3 of the IPPO register. Has allowances for non-CRAN packages, ASReml-R and DiGGer and also the Quarto software.

Usage

create_table_3(
  project_path = getwd(),
  outfile = "1 documentation/table_3.csv",
  aagi_project_code = "AAGI-ALL-SP-003",
  quarto = FALSE,
  digger = FALSE,
  asreml = FALSE
)

Arguments

project_path

The path to the directory of the project to generate the tables for, defaults to the current working directory and recurses into subfolders.

outfile

Character string that provides the file name and full path to the directory where the table will be saved. Defaults to the current project's “1 Documentation” directory with a filename of “table_3.csv”.

aagi_project_code

The AAGI project code to be inserted into the table. Defaults to the current Service and Support project code within the AAGI project. Note that this is NOT the project being serviced but the code within the AAGI project that is allocated for Service and Support, e.g. "AAGI-ALL-SP-003".

quarto

Boolean cite the Quarto software? Defaults to FALSE.

digger

Boolean cite the DiGGer package? Defaults to FALSE.

asreml

Boolean cite the ASReml-R package? Defaults to FALSE.

Value

An invisible NULL, called for its side effects of writing a sheet into an Excel workbook file (the project's IPPO register) on the local disk.

Author(s)

Zhanglong Cao, [email protected], and Adam H. Sparks, [email protected]

See Also

Other create IPPO: run_IPPO_app()

Examples

# after opening an RStudio project for a Service and Support Analysis

create_table_3()

Create IPPO tables list

Description

Traverses directories and imports IPPO register Excel(TM) workbook files and creates a list of tables corresponding to Tables 1-5 in the AAGI IPPO register for all AAGI-CU Service and Support projects.

Usage

list_ippo_tables(dir_path_in, sp)

Arguments

dir_path_in

A string value that provides the path to the top-level directory of the R: drive holding the AAGI-CU Service and Support project files.

sp

A character string providing the AAGI strategic partner that is generating the report, can be full name or two letter string used by AAGI.

Value

A list object that contains tables of IPPO registers organised by AAGI Service and Support project or AAGI R&D Activity.

See Also

Other reporting: create_ippo_report()

Examples

# for macOS
 library(fs)
 R_drive <- "/Volumes/dmp/A-J/AAGI_CCDM_CBADA-GIBBEM-SE21982/"
 list_ippo_tables(
   dir_path_in = path(R_drive, "Projects"),
   sp = "CU"
 )

Run the Shiny IPPO app

Description

Runs a Shiny app where a user can build, edit and download an IPPO registry.

Usage

run_IPPO_app()

Value

An invisible NULL, called for its side-effects of launching a Shiny application.

See Also

Other create IPPO: create_table_3()

Examples

## Not run: 
run_IPPO_app()

## End(Not run)